<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="et">
<context>
    <name>DigiDoc</name>
    <message>
        <source>Container is not open</source>
        <translation>Ümbrik ei ole avatud</translation>
    </message>
    <message>
        <source>Cannot add files to signed container</source>
        <translation>Ei saa lisada faile allakirjutatud ümbrikule</translation>
    </message>
    <message>
        <source>Missing document</source>
        <translation>Puuduv dokument</translation>
    </message>
    <message>
        <source>Cannot add signature to empty container</source>
        <translation>Ei saa lisada allkirja tühjale ümbrikule</translation>
    </message>
    <message>
        <source>Missing signature</source>
        <translation>Allkiri puudub</translation>
    </message>
    <message>
        <source>PIN Incorrect</source>
        <translation>PIN vigane</translation>
    </message>
    <message>
        <source>PIN Locked</source>
        <translation>PIN on lukus</translation>
    </message>
    <message>
        <source>PIN Login failed</source>
        <translation>PIN koodi valideerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Certificate status revoked</source>
        <translation>Sertifikaat on kehtetu</translation>
    </message>
    <message>
        <source>Certificate status unknown</source>
        <translation>Sertifikaadi staatus on teadmata</translation>
    </message>
    <message>
        <source>Check your computer time</source>
        <translation>Kontrollige oma arvuti kella</translation>
    </message>
    <message>
        <source>An error occurred while opening the document.&lt;br /&gt;%1</source>
        <translation>Ümbriku avamisel tekkis viga.&lt;br /&gt;%1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Abi</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Edasi</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Allkiri</translation>
    </message>
    <message>
        <source>Role</source>
        <translation>Roll</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolutsioon</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Linn</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Maakond</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Riik</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Indeks</translation>
    </message>
    <message>
        <source>Sign</source>
        <translation>Kirjutan alla</translation>
    </message>
    <message>
        <source>Add signature</source>
        <translation>Lisa allkiri</translation>
    </message>
    <message>
        <source>Save container</source>
        <translation>Salvesta Ümbrik</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
    <message>
        <source>Keep</source>
        <translation>Jätan alles</translation>
    </message>
    <message>
        <source>Open container</source>
        <translation>Ava ümbrik</translation>
    </message>
    <message>
        <source>Select folder where files will be stored</source>
        <translation>Vali kataloog kuhu failid salvestatakse</translation>
    </message>
    <message>
        <source>This container is signed by you</source>
        <translation>See ümbrik on sinu poolt allakirjutatud</translation>
    </message>
    <message>
        <source>You have not signed this container</source>
        <translation>Sa pole seda ümbrikut allkirjastanud</translation>
    </message>
    <message>
        <source>Container is unsigned</source>
        <translation>Ümbrik ei ole allakirjutatud</translation>
    </message>
    <message>
        <source>Select documents</source>
        <translation>Lisa failid</translation>
    </message>
    <message>
        <source>You added %1 files to container, but these are not signed yet.
Should I keep unsigned documents or remove these?</source>
        <translation>Olete lisanud ümbrikusse %1 faili, kuid pole neid allakirjutanud. Kas jätan allakirjutamata ümbriku alles või kustutan selle?</translation>
    </message>
    <message>
        <source>Skip this intro</source>
        <translation>Ära rohkem mulle seda sissejuhatust näita</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Salvesta fail</translation>
    </message>
    <message>
        <source>Failed to start process &apos;qdigidoccrypto&apos;</source>
        <translation>Protsessi &apos;qdigidoccrypto&apos; käivitamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to start process &apos;qesteidutil&apos;</source>
        <translation>Protsessi &apos;qesteidutil&apos; käivitamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Documents (*.bdoc *.ddoc)</source>
        <translation>Dokumendid (*.bdoc *.ddoc)</translation>
    </message>
    <message>
        <source>No card in reader</source>
        <translation>Kaarti pole lugejas</translation>
    </message>
    <message>
        <source>I want to:</source>
        <translation>Ma tahan:</translation>
    </message>
    <message>
        <source>Sign documents</source>
        <translation>Allkirjastada dokumenti</translation>
    </message>
    <message>
        <source>View signed document content</source>
        <translation>Vaadata allkirjastatud dokumendi sisu</translation>
    </message>
    <message>
        <source>Container content:</source>
        <translation>Ümbriku sisu:</translation>
    </message>
    <message>
        <source>Signatures</source>
        <translation>Allkirjad</translation>
    </message>
    <message>
        <source>Container:</source>
        <translation>Ümbrik:</translation>
    </message>
    <message>
        <source>Use Mobile ID</source>
        <translation>Kasuta Mobiil-ID</translation>
    </message>
    <message>
        <source>Use ID-card</source>
        <translation>Kasuta ID-kaarti</translation>
    </message>
    <message>
        <source>This container is </source>
        <translation>See ümbrik on</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;saveAs&quot;&gt;Save files to disk&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;saveAs&quot;&gt;Salvesta failid kettale&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;email&quot;&gt;Send container to email&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;email&quot;&gt;Saada ümbrik e-postiga&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;print&quot;&gt;Print summary&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;print&quot;&gt;Trüki kinnitusleht&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;browse&quot;&gt;Browse container location&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;browse&quot;&gt;Näita ümbriku asukohta kettal&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Roll ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Roll ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Resolution ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Resolutsioon ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>File already in container</source>
        <translation>Fail on juba ümbrikus</translation>
    </message>
    <message>
        <source>%1&lt;br /&gt;already in container, ovewrite?</source>
        <translation>%1&lt;br /&gt;on juba ümbrikus. Kas kirjutan üle?</translation>
    </message>
    <message>
        <source>Loading data</source>
        <translation>Loen andmeid</translation>
    </message>
    <message>
        <source>Mobile number:</source>
        <translation>Telefoni number:</translation>
    </message>
    <message>
        <source>Personal code:</source>
        <translation>Isikukood:</translation>
    </message>
    <message>
        <source>Encrypt files for secure transfer</source>
        <translation>Krüpteerida faile turvaliseks edastamiseks</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;
&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
Digital signing.&lt;br /&gt;&lt;br /&gt;
Digital signing is equal to physical signing. To sign a document you need an ID-card with a valid and usable signature certificate.&lt;br /&gt;&lt;br /&gt;
Signing is done via PIN2 code&lt;br /&gt;&lt;br /&gt;
Also an active internet connection is needed.&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;
&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
Dokumendi allkirjastamine.&lt;br /&gt;&lt;br /&gt;
Digitaalallkiri on samaväärne füüsilise allkirjaga. Digitaalallkirja andmiseks on vajalik ID-kaart või Mobiil-ID, millel on kehtiv ja kasutatav allkirjastamise sertifikaat.&lt;br /&gt;&lt;br /&gt;
Dokumendi allkirjastamisel on vajalik PIN2 kood.&lt;br /&gt;&lt;br /&gt;
Digitaalallkirja andmiseks on vajalik internetiühendus.
&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;addFile&quot;&gt;Add file&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;addFile&quot;&gt;Lisa fail&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%1 already exists.&lt;br /&gt;Do you want replace it?</source>
        <translation>%1 on juba olemas.&lt;br /&gt;Soovid asendada?</translation>
    </message>
    <message>
        <source>Server access certificate</source>
        <translation>Ligipääsutõend</translation>
    </message>
    <message>
        <source>Did not find any server access certificate!
Start downloading?</source>
        <translation>Puudub ligipääsutõend!
Alustame laadimist?</translation>
    </message>
    <message>
        <source>Error downloading server access certificate!</source>
        <translation>Viga ligipääsutõendi laadimisel!</translation>
    </message>
    <message>
        <source>Error parsing server access certificate result!</source>
        <translation>Viga ligipääsutõendi lugemisel!</translation>
    </message>
    <message>
        <source>Error downloading server access certificate!
%1</source>
        <translation>Viga ligipääsutõendi laadimisel!
%1</translation>
    </message>
    <message>
        <source>Check internet connection</source>
        <translation>Kontrolli interneti ühendust</translation>
    </message>
    <message>
        <source>Personal code is not valid</source>
        <translation>Isikukood on vigane</translation>
    </message>
    <message>
        <source>Failed to save server access certificate file to %1!
%2</source>
        <translation>Viga ligipääsutõendi salvestamisel %1!
%2</translation>
    </message>
    <message>
        <source>NB! Test signature</source>
        <translation>NB! Test allkiri</translation>
    </message>
    <message>
        <source>You dont have permissions to write file %1</source>
        <translation>Teil ei ole piisavalt õigusi et kirjutada faili %1</translation>
    </message>
    <message>
        <source>NB! Invalid signature</source>
        <translation>NB: Vigane allkiri</translation>
    </message>
    <message>
        <source>Error reading server access certificate - empty content!</source>
        <translation>Viga ligipääsutõendi lugemisel - sisu on tühi!</translation>
    </message>
    <message>
        <source>Remove signature %1</source>
        <translation>Eemalda allkiri %1</translation>
    </message>
    <message>
        <source>You dont have suficient privilegs to write this fail into folder %1</source>
        <translation>Sul ei ole piisavalt õigusi, et kirjutada fail kataloogi %1</translation>
    </message>
    <message>
        <source>Documents (*.bdoc *.BDOC *.ddoc *.DDOC)</source>
        <translation>Dokumendid (*.bdoc *.BDOC *.ddoc *.DDOC)</translation>
    </message>
    <message>
        <source>DigiDoc3 client</source>
        <translation>DigiDoc3 klient</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulge</translation>
    </message>
    <message>
        <source>Mobile-ID BDOC allkirjastamine toimub hetkel SK arenduskeskkonnas!</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MobileDialog</name>
    <message>
        <source>Signing in process</source>
        <translation>Toimub allkirjastamine</translation>
    </message>
    <message>
        <source>Request accepted</source>
        <translation>Päring aktsepteeritud</translation>
    </message>
    <message>
        <source>Request timeout</source>
        <translation>Päringu kannatus katkes</translation>
    </message>
    <message>
        <source>User denied or cancelled</source>
        <translation>Kasutaja keeldus või katkestas</translation>
    </message>
    <message>
        <source>Got signature</source>
        <translation>Sain allkirja</translation>
    </message>
    <message>
        <source>Request pending</source>
        <translation>Päring ootel</translation>
    </message>
    <message>
        <source>Mobile-ID not ready, try again later</source>
        <translation>Mobiil-ID pole valmis, proovi hiljem uuesti</translation>
    </message>
    <message>
        <source>Phone absent</source>
        <translation>Telefon ei ole levis</translation>
    </message>
    <message>
        <source>Request sending error</source>
        <translation>Päringu saatmise viga</translation>
    </message>
    <message>
        <source>SIM error</source>
        <translation>SIM kaardi viga</translation>
    </message>
    <message>
        <source>Service internal error</source>
        <translation>Teenuse sisemine viga</translation>
    </message>
    <message>
        <source>Signing with Mobile-ID</source>
        <translation>Allkirjastan Mobiil-ID -ga</translation>
    </message>
    <message>
        <source>Control code: %1</source>
        <translation>Kontrollkood: %1</translation>
    </message>
    <message>
        <source>%v sec</source>
        <translation>%v sek</translation>
    </message>
    <message>
        <source>Connecting to SK server failed!
Please check your internet connection.</source>
        <translation>Viga SK serveriga ühenduse saamisel!
Palun kontrollige internetiühendust.</translation>
    </message>
    <message>
        <source>User is not a Mobile-ID client</source>
        <translatorcomment>Пользователь не является клиентом Mobiil-ID</translatorcomment>
        <translation>Kasutaja ei ole Mobiil-ID klient</translation>
    </message>
</context>
<context>
    <name>PrintSheet</name>
    <message>
        <source>SIGNED FILES</source>
        <translation>ALLKIRJASTATUD FAILID</translation>
    </message>
    <message>
        <source>FILE NAME</source>
        <translation>FAILI NIMI</translation>
    </message>
    <message>
        <source>FILE SIZE</source>
        <translation>FAILI SUURUS</translation>
    </message>
    <message>
        <source>SIGNERS</source>
        <translation>ALLKIRJASTAJAD</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NIMI</translation>
    </message>
    <message>
        <source>PERSONAL CODE</source>
        <translation>ISIKUKOOD</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>AEG</translation>
    </message>
    <message>
        <source>SIGNATURE</source>
        <translation>ALLKIRI</translation>
    </message>
    <message>
        <source>NOTES</source>
        <translation>MÄRKUSED</translation>
    </message>
    <message>
        <source>VALIDITY CONFIRMATION SHEET</source>
        <translation>DIGITAALALLKIRJADE KINNITUSLEHT</translation>
    </message>
    <message>
        <source>NO.</source>
        <translation>nr.</translation>
    </message>
    <message>
        <source>VALIDITY OF SIGNATURE</source>
        <translation>ALLKIRJA KEHTIVUS</translation>
    </message>
    <message>
        <source>VALID</source>
        <translation>KEHTIB</translation>
    </message>
    <message>
        <source>NOT VALID</source>
        <translation>KETHETU</translation>
    </message>
    <message>
        <source>ROLE / RESOLUTION</source>
        <translation>ROLL/RESOLUTSIOON</translation>
    </message>
    <message>
        <source>PLACE OF CONFIRMATION (CITY, STATE, ZIP, COUNTRY)</source>
        <translation>ALLKIRJASTAJA ASUKOHT (LINN, MAAKOND, INDEKS, RIIK)</translation>
    </message>
    <message>
        <source>SERIAL NUMBER OF CERTIFICATE</source>
        <translation>SERTIFIKAADI SEERIANUMBER</translation>
    </message>
    <message>
        <source>ISSUER OF CERTIFICATE</source>
        <translation>SERTIFIKAADI VÄLJAANDJA NIMI</translation>
    </message>
    <message>
        <source>HASH VALUE OF ISSUER&apos;S PUBLIC KEY</source>
        <translation>SERTIFIKAADI VÄLJAANDJA AVALIKU VÕTME LÜHEND</translation>
    </message>
    <message>
        <source>HASH VALUE OF VALIDITY CONFIRMATION (OCSP RESPONSE)</source>
        <translation>KEHTIVUSKINNITUSE SÕNUMILÜHEND</translation>
    </message>
    <message>
        <source>The print out of files listed in the section &lt;b&gt;&quot;Signed Files&quot;&lt;/b&gt; are inseparable part of this Validity Confirmation Sheet.</source>
        <translation>Selle kinnituslehe lahutamatu osa on lõigus &lt;b&gt;&quot;Allkirjastatud failid&quot;&lt;/b&gt; nimetatud failide esitus paberil.</translation>
    </message>
    <message>
        <source>COMPANY</source>
        <translation>ASUTUS</translation>
    </message>
    <message>
        <source>REGISTER CODE</source>
        <translation>REGISTRIKOOD</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>Teadmata</translation>
    </message>
</context>
<context>
    <name>QSigner</name>
    <message>
        <source>Failed to load PKCS#11 module</source>
        <translation>PKCS#11 mooduli laadimine ebaõnnestus</translation>
    </message>
    <message>
        <source>PIN acquisition canceled.</source>
        <translation>PIN koodi sisestamine katkestati.</translation>
    </message>
    <message>
        <source>Signing certificate is not selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to login token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PIN Incorrect</source>
        <translation>PIN vigane</translation>
    </message>
    <message>
        <source>PIN Locked</source>
        <translation>PIN on lukus</translation>
    </message>
    <message>
        <source>Failed to login to token &apos;%1&apos;: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to sign document</source>
        <translation>Dokumendi allkirjastamine ebaõnnestus</translation>
    </message>
</context>
<context>
    <name>RegisterP12</name>
    <message>
        <source>No OCSP PKCS#12 certificate selected</source>
        <translation>Ükski OCSP PKCS#12 sertifikaat ei ole valitud</translation>
    </message>
    <message>
        <source>Failed to copy file</source>
        <translation>Faili kopeerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Select PKCS#12 certificate</source>
        <translation>Valige PKCS#12 sertifikaat</translation>
    </message>
    <message>
        <source>PKCS#12 Certificates (*.p12 *.p12d)</source>
        <translation>PKCS#12 Sertifikaadid (*.p12 *.p12d)</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate installer</source>
        <translation>Ligipääsutõend paigaldamine</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate</source>
        <translation>Ligipääsutõend</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parool</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 server access certificate is available at&lt;br /&gt;
&lt;a href=&quot;http://www.sk.ee/getaccess/?lang=eng&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</source>
        <translation>OCSP PKCS#12 serveri ligipääsu sertifikaadid on võimalik saada&lt;br /&gt;
&lt;a href=&quot;http://www.sk.ee/getaccess/?lang=est&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Container default location</source>
        <translation>Ümbriku loomise vaikekataloog</translation>
    </message>
    <message>
        <source>Role</source>
        <translation>Roll</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolutsioon</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Linn</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Maakond</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Riik</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Indeks</translation>
    </message>
    <message>
        <source>Select folder</source>
        <translation>Vali kataloog</translation>
    </message>
    <message>
        <source>Show signing intro</source>
        <translation>Näita allkirjastamisel sissejuhatust</translation>
    </message>
    <message>
        <source>Same folder</source>
        <translation>Samasse kataloogi</translation>
    </message>
    <message>
        <source>Ask container name</source>
        <translation>Küsi dokumendi nime</translation>
    </message>
    <message>
        <source>Default file type:</source>
        <translation>Vaikimisi faili tüüp:</translation>
    </message>
    <message>
        <source>Save last insert role and resolution</source>
        <translation>Jäta viimati sisestatud roll ja resolutsioon meelde</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Üldine</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Allkiri</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proksi</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Select PKCS#12 certificate</source>
        <translation>Valige PKCS#12 sertifikaat</translation>
    </message>
    <message>
        <source>PKCS#12 Certificates (*.p12 *.p12d)</source>
        <translation>PKCS#12 Sertifikaadid (*.p12 *.p12d)</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate</source>
        <translation>Ligipääsutõend</translation>
    </message>
    <message>
        <source>Certificate</source>
        <translation>Sertifikaat</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parool</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kasutajanimi</translation>
    </message>
    <message>
        <source>If you change file format from .bdoc to .ddoc or vise versa, opened file will not change.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SignatureDialog</name>
    <message>
        <source>Signing time</source>
        <translation>Allkirjastamise aeg</translation>
    </message>
    <message>
        <source>Signature type</source>
        <translation>Allkirja tüüp</translation>
    </message>
    <message>
        <source>Signature format</source>
        <translation>Allkirja formaat</translation>
    </message>
    <message>
        <source>Signed file count</source>
        <translation>Allkirjastatud failide arv</translation>
    </message>
    <message>
        <source>Certificate serialnumber</source>
        <translation>Sertifikaadi seerianumber</translation>
    </message>
    <message>
        <source>Certificate valid at</source>
        <translation>Sertifikaat kehtib alates</translation>
    </message>
    <message>
        <source>Certificate valid until</source>
        <translation>Sertifikaat kehtib kuni</translation>
    </message>
    <message>
        <source>Certificate issuer</source>
        <translation>Sertifikaadi väljaandja</translation>
    </message>
    <message>
        <source>Signer</source>
        <translation>Allkirjastaja</translation>
    </message>
    <message>
        <source>Signer location</source>
        <translation>Allkirjastaja asukoht</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Linn</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Maakond</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Riik</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Indeks</translation>
    </message>
    <message>
        <source>Role / resolution</source>
        <translation>Roll / resolutsioon</translation>
    </message>
    <message>
        <source>Show certificate</source>
        <translation>Näita sertifikaati</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Allkiri</translation>
    </message>
    <message>
        <source>Attribute</source>
        <translation>Atribuut</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Väärtus</translation>
    </message>
    <message>
        <source>Verify</source>
        <translation>Kehtivuskinnitus</translation>
    </message>
    <message>
        <source>Signature is valid</source>
        <translation>Allkiri on kehtiv</translation>
    </message>
    <message>
        <source>Signature is not valid (%1)</source>
        <translation>Allkiri ei ole kehtiv (%1)</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Tundmatu viga</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Aeg</translation>
    </message>
    <message>
        <source>Signature status unknown (%1)</source>
        <translation>Allkirja staatus on teadmata (%1)</translation>
    </message>
    <message>
        <source>Hash value of validity confirmation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SignatureWidget</name>
    <message>
        <source>valid</source>
        <translation>kehtiv</translation>
    </message>
    <message>
        <source>not valid</source>
        <translation>kehtetu</translation>
    </message>
    <message>
        <source>Show details</source>
        <translation>Vaata üksikasju</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
    <message>
        <source>Signed on</source>
        <translation>Allkirjastati</translation>
    </message>
    <message>
        <source>Signature is</source>
        <translation>Allkiri on</translation>
    </message>
    <message>
        <source>time</source>
        <translation>kell</translation>
    </message>
    <message>
        <source>Test signature</source>
        <translation>Test allkiri</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>teadmata</translation>
    </message>
</context>
<context>
    <name>TreeWidget</name>
    <message>
        <source>Save</source>
        <translation>Salvesta</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Salvesta fail</translation>
    </message>
</context>
</TS>
